#!/bin/bash

# Define image name
MYP_RP_IMAGE_NAME="myp-rp"

# Function to build Docker image
build_image() {
    local image_name=$1
    local dockerfile=$2
    local platform=$3

    echo "Building $image_name Docker image for $platform..."

    docker buildx build --platform $platform -t ${image_name}:latest -f $dockerfile .
    if [ $? -eq 0 ]; then
        echo "$image_name Docker image built successfully"
    else
        echo "Error occurred while building $image_name Docker image"
        exit 1
    fi
}

# Create and use a builder instance (if not already created)
BUILDER_NAME="myp-rp-arm64-builder"
docker buildx create --name $BUILDER_NAME --use || docker buildx use $BUILDER_NAME

# Build myp-rp image
build_image "$MYP_RP_IMAGE_NAME" "$PWD/Dockerfile" "linux/arm64"

# Remove the builder instance
docker buildx rm $BUILDER_NAME
